@@ -21,14 +21,15 @@
  */
 #include "skgunitplugin.h"
 
-#include <KInputDialog>
-#include <KActionCollection>
-#include <KAction>
-#include <KAboutData>
-#include <KGenericFactory>
-#include <KStandardDirs>
-#include <KComponentData>
-#include <QProcess>
+#include <float.h>
+
+#include <kactioncollection.h>
+#include <kaboutdata.h>
+#include <kpluginfactory.h>
+
+#include <qaction.h>
+#include <qinputdialog.h>
+#include <qprocess.h>
 
 #include "skgunitpluginwidget.h"
 #include "skgunitboardwidget.h"
@@ -44,14 +45,9 @@
  * This plugin factory.
  */
 K_PLUGIN_FACTORY(SKGUnitPluginFactory, registerPlugin<SKGUnitPlugin>();)
-/**
- * This plugin export.
- */
-K_EXPORT_PLUGIN(SKGUnitPluginFactory("skrooge_unit", "skrooge_unit"))
 
 SKGUnitPlugin::SKGUnitPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
-    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL),
-      m_splitShareAction(NULL)
+    : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -60,8 +56,7 @@ SKGUnitPlugin::SKGUnitPlugin(QWidget* iWidget, QObject* iParent, const QVariantL
 SKGUnitPlugin::~SKGUnitPlugin()
 {
     SKGTRACEINFUNC(10);
-    m_currentBankDocument = NULL;
-    m_splitShareAction = NULL;
+    m_currentBankDocument = nullptr;
 }
 
 bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -69,23 +64,23 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) {
+    if (m_currentBankDocument == nullptr) {
         return false;
     }
 
-    setComponentData(KGlobal::mainComponent());
-    setXMLFile("../skrooge_unit/skrooge_unit.rc");
+    setComponentName(QStringLiteral("skrooge_unit"), title());
+    setXMLFile(QStringLiteral("skrooge_unit.rc"));
 
     // Menu
-    m_splitShareAction = new KAction(KIcon("skrooge_split_stock"), i18nc("Verb", "Split share..."), this);
-    connect(m_splitShareAction, SIGNAL(triggered(bool)), this, SLOT(onSplitShare()));
-    m_splitShareAction->setShortcut(Qt::ALT + Qt::Key_Slash);
-    registerGlobalAction("edit_split_stock", m_splitShareAction);
+    auto actSplitShare = new QAction(SKGServices::fromTheme(QStringLiteral("format-text-strikethrough")), i18nc("Verb", "Split share..."), this);
+    connect(actSplitShare, &QAction::triggered, this, &SKGUnitPlugin::onSplitShare);
+    actionCollection()->setDefaultShortcut(actSplitShare, Qt::ALT + Qt::Key_Slash);
+    registerGlobalAction(QStringLiteral("edit_split_stock"), actSplitShare, QStringList() << QStringLiteral("unit"), 1, 1, 310);  // TODO(Stephane MANKOWSKI): must be a share
 
     // -----------
-    KAction* act = new KAction(KIcon(icon()), i18nc("Verb", "Delete unused units"), this);
-    connect(act, SIGNAL(triggered(bool)), this, SLOT(deleteUnusedUnits()));
-    registerGlobalAction("clean_delete_unused_units", act);
+    auto act = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb", "Delete unused units"), this);
+    connect(act, &QAction::triggered, this, &SKGUnitPlugin::deleteUnusedUnits);
+    registerGlobalAction(QStringLiteral("clean_delete_unused_units"), act);
     return true;
 }
 
@@ -106,12 +101,17 @@ QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
 SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) {
-        return new SKGUnitBoardWidget(m_currentBankDocument);
+        return new SKGUnitBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
     } else {
-        return new SKGHtmlBoardWidget(m_currentBankDocument,
+        // Get QML mode for dashboard
+        KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
+        KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
+        bool qml = sklItem->property().toBool();
+
+        return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex),
-                                      KStandardDirs().findResource("data", "skrooge/html/default/portfolio.html"),
-                                      QStringList() << "v_operation_display");
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/portfolio.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
+                                      QStringList() << QStringLiteral("v_operation_display"));
     }
 }
 
@@ -119,73 +119,62 @@ void SKGUnitPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
-        bool test = (m_currentBankDocument->getDatabase() != NULL);
-        if (m_splitShareAction) {
-            SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
-            if (selection.count() == 1 && selection.at(0).getRealTable() == "unit") {
-                SKGUnitObject unit(selection.at(0));
-                m_splitShareAction->setEnabled(unit.getType() == SKGUnitObject::SHARE);
-            } else {
-                m_splitShareAction->setEnabled(false);
-            }
-        }
-
         // Automatic download
-        if (test) {
-            QString doc_id = m_currentBankDocument->getUniqueIdentifier();
-            if (m_docUniqueIdentifier != doc_id) {
-                m_docUniqueIdentifier = doc_id;
-                // Check if current unit is existing
-                KLocale* loc = KGlobal::locale();
-                bool exist = false;
-                SKGError err = m_currentBankDocument->existObjects("unit", "", exist);
-                IFOK(err) {
-                    if (!exist) {
-                        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create default unit"), err);
-                        IFOK(err) {
-                            // Create default unit
-                            SKGUnitObject unit;
-                            err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, loc->currencyCode(), unit);
-
-                            // The file is considered has not modified
-                            m_currentBankDocument->setFileNotModified();
+        QString doc_id = m_currentBankDocument->getUniqueIdentifier();
+        if (m_docUniqueIdentifier != doc_id) {
+            m_docUniqueIdentifier = doc_id;
+            // Check if current unit is existing
+            bool exist = false;
+            SKGError err = m_currentBankDocument->existObjects(QStringLiteral("unit"), QStringLiteral(""), exist);
+            IFOK(err) {
+                if (!exist) {
+                    SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create default unit"), err);
+                    IFOK(err) {
+                        // Create default unit
+                        SKGUnitObject unit;
+                        QString unitS = QLocale().currencySymbol(QLocale::CurrencyIsoCode);
+                        if (!unitS.isEmpty()) {
+                            err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, unitS, unit);
                         }
-                    } else if (skgunit_settings::download_on_open()) {
-                        // Check frequency
-                        QString lastAutomaticDownload = m_currentBankDocument->getParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD");
-                        if (lastAutomaticDownload.isEmpty()) {
-                            lastAutomaticDownload = "1970-01-01";
+
+                        // The file is considered has not modified
+                        m_currentBankDocument->setFileNotModified();
+                    }
+                } else if (skgunit_settings::download_on_open()) {
+                    // Check frequency
+                    QString lastAutomaticDownload = m_currentBankDocument->getParameter(QStringLiteral("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD"));
+                    if (lastAutomaticDownload.isEmpty()) {
+                        lastAutomaticDownload = QStringLiteral("1970-01-01");
+                    }
+                    QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, QStringLiteral("yyyy-MM-dd"));
+                    if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgunit_settings::download_frequency() == 0) ||
+                        (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
+                        (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
+
+                    {
+                        // Download all units
+                        SKGObjectBase::SKGListSKGObjectBase selection;
+                        err = m_currentBankDocument->getObjects(QStringLiteral("unit"), QStringLiteral(""), selection);
+                        int nb = selection.count();
+                        SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Automatic download of units"), err, nb);
+                        for (int i = 0; !err && i < nb; ++i) {
+                            SKGUnitObject unit(selection.at(i));
+                            err = SKGUnitPluginWidget::downloadUnitValue(unit, SKGUnitPluginWidget::getDownloadModeFromSettings());
+
+                            // Send message
+                            IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The unit '%1' has been downloaded", unit.getDisplayName()), SKGDocument::Hidden));
+
+                            IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                         }
-                        QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
-                        if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgunit_settings::download_frequency() == 0) ||
-                            (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
-                            (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
 
-                        {
-                            // Download all units
-                            SKGObjectBase::SKGListSKGObjectBase selection;
-                            err = m_currentBankDocument->getObjects("unit", "", selection);
-                            int nb = selection.count();
-                            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Automatic download of units"), err, nb);
-                            for (int i = 0; !err && i < nb; ++i) {
-                                SKGUnitObject unit(selection.at(i));
-                                err = SKGUnitPluginWidget::downloadUnitValue(unit, SKGUnitPluginWidget::getDownloadModeFromSettings());
-
-                                // Send message
-                                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The unit '%1' has been downloaded", unit.getDisplayName()), SKGDocument::Hidden));
-
-                                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
-                            }
-
-                            // Memorize the last download date
-                            IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd")))
-                        }
+                        // Memorize the last download date
+                        IFOKDO(err, m_currentBankDocument->setParameter(QStringLiteral("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD"), QDate::currentDate().toString(QStringLiteral("yyyy-MM-dd"))))
                     }
                 }
-
-                // Display error
-                SKGMainPanel::displayErrorMessage(err);
             }
+
+            // Display error
+            SKGMainPanel::displayErrorMessage(err);
         }
     }
 }
@@ -193,14 +182,15 @@ void SKGUnitPlugin::refresh()
 SKGTabPage* SKGUnitPlugin::getWidget()
 {
     SKGTRACEINFUNC(10);
-    return new SKGUnitPluginWidget(m_currentBankDocument);
+    return new SKGUnitPluginWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
 }
 
 QWidget* SKGUnitPlugin::getPreferenceWidget()
 {
     SKGTRACEINFUNC(10);
-    QWidget* w = new QWidget();
+    auto w = new QWidget();
     ui.setupUi(w);
+    connect(ui.kcfg_download_on_open, &QCheckBox::toggled, ui.kcfg_download_frequency, &KComboBox::setEnabled);
 
     return w;
 }
@@ -217,7 +207,7 @@ QString SKGUnitPlugin::title() const
 
 QString SKGUnitPlugin::icon() const
 {
-    return "view-currency-list";
+    return QStringLiteral("taxes-finances");
 }
 
 QString SKGUnitPlugin::toolTip() const
@@ -260,9 +250,9 @@ void SKGUnitPlugin::onSplitShare()
         int nb = selection.count();
         if (nb == 1) {
             bool ok = false;
-            double ratio = KInputDialog::getDouble(i18nc("Question", "Split share"),
+            double ratio = QInputDialog::getDouble(SKGMainPanel::getMainPanel(), i18nc("Question", "Split share"),
                                                    i18nc("Question", "Ratio (2 means 2-for-1, 0.5 means 1-for-2):"), 2.0,
-                                                   0, DBL_MAX, 8, &ok, SKGMainPanel::getMainPanel());
+                                                   0, DBL_MAX, 8, &ok);
             if (ok) {
                 SKGUnitObject unit(selection.at(0));
                 SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Split stock '%1' by '%2'", unit.getName(), ratio), err);
@@ -285,14 +275,15 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEINFUNC(10);
     SKGAdviceList output;
+    output.reserve(20);
 
     // Get all currencies
     SKGStringListList result;
-    m_currentBankDocument->executeSelectSqliteOrder("SELECT (SELECT count(1) FROM operation WHERE operation.rc_unit_id=unit.id), unit.t_name FROM unit WHERE t_type='C' GROUP BY t_name ORDER BY count(1) DESC", result);
+    m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT (SELECT count(1) FROM operation WHERE operation.rc_unit_id=unit.id), unit.t_name FROM unit WHERE t_type='C' GROUP BY t_name ORDER BY count(1) DESC"), result);
     int nb = result.count();
 
     // Check primary unit
-    if (!iIgnoredAdvice.contains("skgunitplugin_primaryunit")) {
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_primaryunit"))) {
         if (m_currentBankDocument->getPrimaryUnit().Name.isEmpty() && nb > 1) {
             // Get unit
             QString unit = result.at(1).at(1);
@@ -302,7 +293,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(8);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a primary currency"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "To avoid misunderstanding and conflicts between units at conversion time, you should define a primary currency. It is the currency against which all other will be converted"));
-            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            SKGAdvice::SKGAdviceActionList autoCorrections;
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Set '%1' as primary currency", unit);
@@ -325,7 +316,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Check secondary unit
-    if (!iIgnoredAdvice.contains("skgunitplugin_secondaryunit")) {
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_secondaryunit"))) {
         if (m_currentBankDocument->getSecondaryUnit().Name.isEmpty() && nb > 1) {
             // Get unit
             QString unit = result.at(1).at(1);
@@ -335,7 +326,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(2);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a secondary currency"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "When a secondary unit is defined, Skrooge will display it as an additional amount information."));
-            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            SKGAdvice::SKGAdviceActionList autoCorrections;
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Set '%1' as secondary currency", unit);
@@ -356,9 +347,11 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Shares not downloaded
-    if (!iIgnoredAdvice.contains("skgunitplugin_notdownloaded")) {
-        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)", result);
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_notdownloaded"))) {
+        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)"), result);
         nb = result.count();
+        SKGAdvice::SKGAdviceActionList autoCorrections;
+        autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
             QStringList line = result.at(i);
@@ -369,8 +362,8 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setUUID("skgunitplugin_notdownloaded|" % unit);
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has not been downloaded for more than a month", unit));
-            ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget download units to have a better view of your accounts"));
-            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "Do not forget download units to have a better view of your accounts"));
+            autoCorrections.resize(0);
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Edit units");
@@ -381,7 +374,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             if (!internet_code.isEmpty()) {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Download '%1'", unit);
-                a.IconName = "download";
+                a.IconName = QStringLiteral("download");
                 a.IsRecommended = true;
                 autoCorrections.push_back(a);
             }
@@ -391,26 +384,28 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Check unused units
-    if (!iIgnoredAdvice.contains("skgunitplugin_unused")) {
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_unused"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects("unit", "t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)", exist);
+        m_currentBankDocument->existObjects(QStringLiteral("unit"), QStringLiteral("t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)"), exist);
         if (exist) {
             SKGAdvice ad;
-            ad.setUUID("skgunitplugin_unused");
+            ad.setUUID(QStringLiteral("skgunitplugin_unused"));
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused units"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no operation is registered."));
             QStringList autoCorrections;
-            autoCorrections.push_back("skg://clean_delete_unused_units");
+            autoCorrections.push_back(QStringLiteral("skg://clean_delete_unused_units"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
 
     // Check unit too complex
-    if (!iIgnoredAdvice.contains("skgunitplugin_amountnotdefined")) {
-        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_unit WHERE t_type IN ('2','C') AND f_CURRENTAMOUNT=1", result);
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_amountnotdefined"))) {
+        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name FROM v_unit WHERE t_type IN ('2','C') AND f_CURRENTAMOUNT=1"), result);
         nb = result.count();
+        SKGAdvice::SKGAdviceActionList autoCorrections;
+        autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
             QStringList line = result.at(i);
@@ -421,7 +416,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(9);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "The amount of the unit '%1' is not defined", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "'%1' has an amount defined at 1. Most of the time this is not normal and causes wrong computation. Check if this is normal.", unit));
-            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            autoCorrections.resize(0);
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Edit units");
@@ -435,20 +430,22 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Check unit too complex
-    if (!iIgnoredAdvice.contains("skgunitplugin_toocomplex")) {
-        m_currentBankDocument->executeSelectSqliteOrder("SELECT A.t_name FROM unit A, unit B, unit C, unit D WHERE A.rd_unit_id=B.id AND B.rd_unit_id=C.id AND C.rd_unit_id=D.id", result);
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_toocomplex"))) {
+        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT A.t_name FROM unit A, unit B, unit C, unit D WHERE A.rd_unit_id=B.id AND B.rd_unit_id=C.id AND C.rd_unit_id=D.id"), result);
         nb = result.count();
+        SKGAdvice::SKGAdviceActionList autoCorrections;
+        autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
             QStringList line = result.at(i);
             QString unit = line.at(0);
 
             SKGAdvice ad;
-            ad.setUUID("skgunitplugin_toocomplex");
+            ad.setUUID(QStringLiteral("skgunitplugin_toocomplex"));
             ad.setPriority(9);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "The definition of the unit '%1' is too complex", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "'%1' is defined relatively to another unit defined relatively to a third one. This is too complex and not supported by Skrooge.", unit));
-            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            autoCorrections.resize(0);
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Edit units");
@@ -462,9 +459,11 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Unit with very old values
-    if (!iIgnoredAdvice.contains("skgunitplugin_veryold")) {
-        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=(SELECT date('now', '-50 year')))", result);
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_veryold"))) {
+        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=(SELECT date('now', '-50 year')))"), result);
         nb = result.count();
+        SKGAdvice::SKGAdviceActionList autoCorrections;
+        autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
             QStringList line = result.at(i);
@@ -475,7 +474,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(3);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has very old values", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Unit '%1' has very old values. Check if this is normal.", unit));
-            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            autoCorrections.resize(0);
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Edit units");
@@ -489,17 +488,17 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // No decimal settings
-    if (!iIgnoredAdvice.contains("skgunitplugin_decimalsymbol") && KGlobal::locale()->monetaryDecimalSymbol().isEmpty()) {
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_decimalsymbol")) && QLocale().decimalPoint().isNull()) {
         SKGAdvice ad;
-        ad.setUUID("skgunitplugin_decimalsymbol");
+        ad.setUUID(QStringLiteral("skgunitplugin_decimalsymbol"));
         ad.setPriority(9);
         ad.setShortMessage(i18nc("Advice on making the best (short)", "No decimal symbol defined"));
         ad.setLongMessage(i18nc("Advice on making the best (long)", "In KDE localization settings, there is no decimal symbol defined for currencies. This could be confusing."));
-        QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+        SKGAdvice::SKGAdviceActionList autoCorrections;
         {
             SKGAdvice::SKGAdviceAction a;
             a.Title = i18nc("Advice on making the best (action)", "Edit KDE settings");
-            a.IconName = "configure";
+            a.IconName = QStringLiteral("configure");
             a.IsRecommended = false;
             autoCorrections.push_back(a);
         }
@@ -514,7 +513,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_primaryunit|"))) {
         if (iSolution == 1) {
-            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
+            SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
         } else {
             // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 26);
@@ -545,7 +544,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_secondaryunit|"))) {
         if (iSolution == 1) {
-            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
+            SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
         } else {
             // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
@@ -576,7 +575,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_notdownloaded|"))) {
         if (iSolution == 0) {
-            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
+            SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
         } else {
             // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
@@ -596,10 +595,10 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
                                          iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_toocomplex")) ||
                                          iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_amountnotdefined|")))
               ) {
-        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
+        SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_decimalsymbol"))) {
-        QProcess::execute("kcmshell4", QStringList() << "language");
+        QProcess::execute(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("formats"));
         return SKGError();
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
@@ -610,10 +609,10 @@ void SKGUnitPlugin::deleteUnusedUnits() const
     SKGError err;
     _SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
-        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused units")  , err);
+        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused units"), err);
 
         // Modification of payee object
-        QString sql = "DELETE FROM unit WHERE t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)";
+        QString sql = QStringLiteral("DELETE FROM unit WHERE t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)");
         err = m_currentBankDocument->executeSqliteOrder(sql);
     }
 
@@ -627,4 +626,4 @@ void SKGUnitPlugin::deleteUnusedUnits() const
     SKGMainPanel::displayErrorMessage(err);
 }
 
-#include "skgunitplugin.moc"
+#include <skgunitplugin.moc>
